@@ -22,7 +22,7 @@
 #include <string.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-macros.h>
+
 #include "gok-log.h"
 #include "gok-utf8-word-complete.h"
 
@@ -75,13 +75,12 @@ static void utf8_word_prediction_free (WordPrediction *prediction);
 
 /* 
  * This macro initializes GokUtf8WordComplete with the GType system 
- *   and defines ..._class_init and ..._instance_init functions 
+ *   and defines ..._class_init and ..._init functions and a ..._parent_class pointer
  */
-GNOME_CLASS_BOILERPLATE (GokUTF8WordComplete, gok_utf8_wordcomplete,
-			 GokWordComplete, GOK_TYPE_WORDCOMPLETE)
+G_DEFINE_TYPE (GokUTF8WordComplete, gok_utf8_wordcomplete, GOK_TYPE_WORDCOMPLETE)
 
 static void
-gok_utf8_wordcomplete_instance_init (GokUTF8WordComplete *complete)
+gok_utf8_wordcomplete_init (GokUTF8WordComplete *complete)
 {
 	complete->word_list = NULL;
 	complete->word_list_end = NULL;
@@ -93,7 +92,7 @@ gok_utf8_wordcomplete_instance_init (GokUTF8WordComplete *complete)
 static void
 gok_utf8_wordcomplete_class_init (GokUTF8WordCompleteClass *klass)
 {
-	GokWordCompleteClass *word_complete_class = (GokWordCompleteClass *) klass;
+	GokWordCompleteClass *word_complete_class = GOK_WORDCOMPLETE_CLASS (klass);
 	word_complete_class->open = utf8_wordcomplete_open;
 	word_complete_class->close = utf8_wordcomplete_close;
 	word_complete_class->predict_string = utf8_wordcomplete_predict_string;
